FileInfo class

Represents a file for validation purposes.

This is a platform-agnostic representation that works with File, XFile, bytes, or any file source.

Constructors

FileInfo({required String name, required int size, String? mimeType, String? extension})
Creates a FileInfo instance.

Properties

extension String
The file extension (derived from name if not provided).
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String?
The MIME type of the file (optional).
final
name String
The file name including extension.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
The file size in bytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited