fallbackError property
E?
fallbackError
final
The error to return if all validators fail. If null, returns the last error from the validators.
Implementation
final E? fallbackError;
The error to return if all validators fail. If null, returns the last error from the validators.
final E? fallbackError;