hasCachedResult property
bool
get
hasCachedResult
Returns true if there is a cached result available.
Implementation
bool get hasCachedResult => _hasValidated;
Returns true if there is a cached result available.
bool get hasCachedResult => _hasValidated;