peek method
Returns the cached result for value, or null if not cached.
Does not update access order (use validate for that).
Implementation
ValidationResult<T, E>? peek(T value) => _cache[value];
Returns the cached result for value, or null if not cached.
Does not update access order (use validate for that).
ValidationResult<T, E>? peek(T value) => _cache[value];