MapValue<TIn, TOut, E> class
Maps a validator's output value.
final validator = MapValue<String, String, String>(
validator: trimRule,
mapper: (value) => value.toLowerCase(),
);
- Inheritance
- Available extensions
Constructors
Properties
Methods
-
andThen(
Formix< T, E> next) → Formix<T, E> -
Available on Formix<
Chains this validator withT, E> , provided by the FormixExtensions extensionnext, runningnextonly if this passes. -
cached(
) → CachedFormix< T, E> -
Available on Formix<
Wraps this validator with single-value caching.T, E> , provided by the FormixExtensions extension -
lazy(
) → LazyFormix< T, E> -
Available on Formix<
Creates a lazy validator that defers instantiation until first use.T, E> , provided by the FormixExtensions extension -
lruCached(
{int maxSize = 10}) → LruCachedFormix< T, E> -
Available on Formix<
Wraps this validator with LRU (Least Recently Used) caching.T, E> , provided by the FormixExtensions extension -
mapError<
E2> (E2 mapper(E error)) → Formix< T, E2> -
Available on Formix<
Maps errors from typeT, E> , provided by the FormixExtensions extensionEto typeE2. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
optional(
{bool isEmpty(T value)?}) → Formix< T, E> -
Available on Formix<
Makes this validator optional - skips validation when empty.T, E> , provided by the FormixExtensions extension -
recover(
T onError(List< E> errors)) → Formix<T, E> -
Available on Formix<
Recovers from validation errors with a default value.T, E> , provided by the FormixExtensions extension -
tap(
{void onValid(T value)?, void onInvalid(List< E> errors)?}) → Formix<T, E> -
Available on Formix<
Applies side effects without affecting validation.T, E> , provided by the FormixExtensions extension -
toString(
) → String -
A string representation of this object.
inherited
-
validate(
TIn value) → ValidationResult< TIn, E> -
Validates
valueand returns a ValidationResult.override -
when(
bool condition(T value)) → Formix< T, E> -
Available on Formix<
Conditionally applies this validator based onT, E> , provided by the FormixExtensions extensioncondition. -
whenNot(
bool condition(T value)) → Formix< T, E> -
Available on Formix<
Conditionally skips this validator based onT, E> , provided by the FormixExtensions extensioncondition. -
withMessageFormatter(
ErrorMessageFormatter< E> formatter) → Formix<T, String> -
Available on Formix<
Maps errors to user-facing messages usingT, E> , provided by the FormixExtensions extensionformatter.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited