isEmpty property
Predicate that determines if the value should be considered empty. If empty, validation is skipped and returns valid.
Implementation
final bool Function(T value) isEmpty;
Predicate that determines if the value should be considered empty. If empty, validation is skipped and returns valid.
final bool Function(T value) isEmpty;