map<R> method
Maps the value if valid, returns same invalid result otherwise.
Implementation
@override
ValidationResult<R, E> map<R>(R Function(T value) transform) =>
Valid(transform(value));
Maps the value if valid, returns same invalid result otherwise.
@override
ValidationResult<R, E> map<R>(R Function(T value) transform) =>
Valid(transform(value));