errorOrNull property
E?
get
errorOrNull
Returns the first error if invalid, or null if valid.
Implementation
E? get errorOrNull;
Returns the first error if invalid, or null if valid.
E? get errorOrNull;