map<R> abstract method
Maps the value if valid, returns same invalid result otherwise.
Implementation
ValidationResult<R, E> map<R>(R Function(T value) transform);
Maps the value if valid, returns same invalid result otherwise.
ValidationResult<R, E> map<R>(R Function(T value) transform);