reset method
void
reset()
Resets the lazy validator, allowing the factory to be called again.
The next validate call will create a new instance.
final lazy = Validate.lazy(() => createValidator());
lazy.validate('test'); // Creates instance
lazy.reset(); // Discards instance
lazy.validate('test'); // Creates new instance
Implementation
void reset() {
_instance = null;
}